@@ -1,18 +1,17 @@
 # Copyright (c) 2011, Canonical Ltd
 #
 # This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, version 3 only.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
+# GNU Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Affero General Public License
+# You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
-# GNU Affero General Public License version 3 (see the file LICENSE).
+# GNU Lesser General Public License version 3 (see the file LICENSE).
 
 """Publish OOPS reports over amqp."""
 
@@ -22,7 +21,7 @@ from hashlib import md5
 from threading import local
 
 from amqplib import client_0_8 as amqp
-from bson import dumps
+from anybson import dumps
 
 from utils import (
     amqplib_error_types,
